@@ -1,5 +1,5 @@
 
-/* Generated data (by glib-mkenums) */
+
 
 #ifndef __LIBYELP_TYPES_H__
 #define __LIBYELP_TYPES_H__
@@ -8,28 +8,28 @@
 
 G_BEGIN_DECLS
 
-#include <libyelp/yelp-document.h>
+#include "yelp-document.h"
 #define YELP_TYPE_DOCUMENT_SIGNAL yelp_document_signal_get_type()
 GType yelp_document_signal_get_type (void);
-#include <libyelp/yelp-location-entry.h>
+#include "yelp-location-entry.h"
 #define YELP_TYPE_LOCATION_ENTRY_FLAGS yelp_location_entry_flags_get_type()
 GType yelp_location_entry_flags_get_type (void);
-#include <libyelp/yelp-settings.h>
+#include "yelp-settings.h"
 #define YELP_TYPE_SETTINGS_COLOR yelp_settings_color_get_type()
 GType yelp_settings_color_get_type (void);
 #define YELP_TYPE_SETTINGS_FONT yelp_settings_font_get_type()
 GType yelp_settings_font_get_type (void);
 #define YELP_TYPE_SETTINGS_ICON yelp_settings_icon_get_type()
 GType yelp_settings_icon_get_type (void);
-#include <libyelp/yelp-uri.h>
+#include "yelp-uri.h"
 #define YELP_TYPE_URI_DOCUMENT_TYPE yelp_uri_document_type_get_type()
 GType yelp_uri_document_type_get_type (void);
-#include <libyelp/yelp-view.h>
+#include "yelp-view.h"
 #define YELP_TYPE_VIEW_STATE yelp_view_state_get_type()
 GType yelp_view_state_get_type (void);
 G_END_DECLS
 
 #endif /* __LIBYELP_TYPES_H__ */
 
-/* Generated data ends here */
+
 
